@@ -30,6 +30,7 @@ sigma <- 1
 set.seed(888)
 rand_nums <- rnorm(n, mu, sigma)
 ttest <- tidy(t.test(rand_nums))
+ttest_lower_conf <- tidy(t.test(rand_nums, conf.level = 0.8))
 dat <- data.frame(x = rand_nums)
 
 set.seed(456765)
@@ -47,35 +48,47 @@ test_that('Bootstrap estimate of mean is close to estimate of mean from normal d
 
   single_bca_res <- int_bca(bt_norm, stats, .fn = get_stats)
 
+  single_bca_res_lower_conf <- int_bca(bt_norm, stats, .fn = get_stats, alpha = 0.2)
+
   expect_equal(ttest$conf.low,
                single_pct_res$.lower,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(unname(ttest$estimate),
                single_pct_res$.estimate,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(ttest$conf.high,
                single_pct_res$.upper,
-               tolerance = 0.01)
+               tolerance = 0.001)
 
   expect_equal(ttest$conf.low,
                single_t_res$.lower,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(unname(ttest$estimate),
                single_t_res$.estimate,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(ttest$conf.high,
                single_pct_res$.upper,
-               tolerance = 0.01)
+               tolerance = 0.001)
 
   expect_equal(ttest$conf.low,
                single_bca_res$.lower,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(unname(ttest$estimate),
                single_bca_res$.estimate,
-               tolerance = 0.01)
+               tolerance = 0.001)
   expect_equal(ttest$conf.high,
                single_bca_res$.upper,
-               tolerance = 0.01)
+               tolerance = 0.001)
+
+  expect_equal(ttest_lower_conf$conf.low,
+               single_bca_res_lower_conf$.lower,
+               tolerance = 0.001)
+  expect_equal(unname(ttest_lower_conf$estimate),
+               single_bca_res_lower_conf$.estimate,
+               tolerance = 0.001)
+  expect_equal(ttest_lower_conf$conf.high,
+               single_bca_res_lower_conf$.upper,
+               tolerance = 0.001)
 })
 
 # ------------------------------------------------------------------------------
@@ -193,6 +206,10 @@ context("boot_ci() Input Validation")
 test_that("bad input", {
   expect_error(int_pctl(bt_small, id))
   expect_error(int_pctl(bt_small, junk))
+  expect_error(int_pctl(bt_small, stats, alpha = c(0.05, 0.2)))
+  expect_error(int_t(bt_small, stats, alpha = "potato"))
+  expect_error(int_bca(bt_small, stats, alpha = 1:2, .fn = get_stats))
+
 
   bad_bt_norm <-
     bt_norm %>%
